import random

def udirdagch_songo(ner_degshigchid):
    '''
    Удирдагчыг санамсаргүй байдлаар сонгон буцаана

    Parameters:
        ner_degshigchid(list): Нэр дэвшиж буй намууд
    Return:
        string: Сонгогдсон нэр
    '''
    return random.choice(ner_degshigchid)